@@ -2,7 +2,7 @@ package Mail::DMARC::Report::Aggregate;
 use strict;
 use warnings;
 
-our $VERSION = '1.20191025';
+our $VERSION = '1.20200108';
 
 use Carp;
 use Data::Dumper;
@@ -69,7 +69,7 @@ EO_XML
 sub get_record_as_xml {
     my $self = shift;
 
-    my $rec_xml;
+    my $rec_xml = '';
     foreach my $rec ( @{ $self->{record} } ) {
         $rec_xml .= "\t<record>\n";
         my $ip = $rec->{row}{source_ip} or croak "no source IP!?";
@@ -199,7 +199,7 @@ Mail::DMARC::Report::Aggregate - aggregate report object
 
 =head1 VERSION
 
-version 1.20191025
+version 1.20200108
 
 =head1 DESCRIPTION
 
@@ -327,7 +327,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Matt Simerson.
+This software is copyright (c) 2020 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
