@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store::SQL;
-our $VERSION = '1.20240314';
+our $VERSION = '1.20200108';
 use strict;
 use warnings;
 
@@ -84,7 +84,7 @@ sub next_todo {
     my ( $self ) = @_;
 
     if ( ! exists $self->{ _todo_list } ) {
-        $self->{_todo_list} = $self->query( $self->grammar->select_todo_query, [ $self->time ] );
+        $self->{_todo_list} = $self->query( $self->grammar->select_todo_query, [ time ] );
         return if ! $self->{_todo_list};
     }
 
@@ -110,7 +110,8 @@ sub retrieve_todo {
 
     # this method extracts the data from the SQL tables and populates a
     # list of Aggregate report objects with them.
-    my $reports = $self->query( $self->grammar->select_todo_query, [ $self->time ] );
+    my $reports = $self->query( $self->grammar->select_todo_query, [ time ] );
+
     my @reports_todo;
     return \@reports_todo if ! scalar @$reports;
 
@@ -141,13 +142,13 @@ sub delete_report {
     if (scalar @row_ids) {
         foreach my $table (qw/ report_record_spf report_record_dkim report_record_reason /) {
             print "deleting $table rows " . join(',', @row_ids) . "\n" if $self->verbose;
-            eval { $self->query( $self->grammar->delete_from_where_record_in($table), \@row_ids); };
+            eval { $self->query( $self->grammar->delete_from_where_record_in($table, \@row_ids)); };
             # warn $@ if $@;
         }
     }
     foreach my $table (qw/ report_policy_published report_record report_error /) {
         print "deleting $table rows for report $report_id\n" if $self->verbose;
-        eval { $self->query( $self->grammar->delete_from_where_report($table), [$report_id] ); };
+        eval { $self->query( $self->grammar->delete_from_where_report( $table, [$report_id] )); };
         # warn $@ if $@;
     }
 
@@ -206,7 +207,7 @@ sub get_report_id {
     # They aggregate on the From domain, where the DMARC policy was discovered
         $ids = $self->query(
         $self->grammar->select_id_with_end,
-        [ $from_dom_id, $self->time, $author_id ]
+        [ $from_dom_id, time, $author_id ]
         );
     };
 
@@ -432,7 +433,7 @@ sub insert_agg_record {
 sub insert_error {
     my ( $self, $rid, $error ) = @_;
     # wait >5m before trying to deliver this report again
-    $self->query($self->grammar->insert_error(0), [$self->time + (5*60), $rid]);
+    $self->query($self->grammar->insert_error(0), [time + (5*60), $rid]);
 
     return $self->query(
         $self->grammar->insert_error(1),
@@ -452,7 +453,7 @@ sub insert_rr_dkim {
     my ( $self, $row_id, $dkim ) = @_;
     my (@fields, @values);
     foreach ( qw/ domain selector result human_result / ) {
-        next if ! defined $dkim->{$_};
+        next if ! $dkim->{$_};
         if ( 'domain' eq $_ ) {
             push @fields, 'domain_id';
             push @values, $self->get_domain_id( $dkim->{domain} );
@@ -470,7 +471,7 @@ sub insert_rr_spf {
     my ( $self, $row_id, $spf ) = @_;
     my (@fields, @values);
     for ( qw/ domain scope result / ) {
-        next if ! defined $spf->{$_};
+        next if ! $spf->{$_};
         if ( 'domain' eq $_ ) {
             push @fields, 'domain_id';
             push @values, $self->get_domain_id( $spf->{domain} );
@@ -520,12 +521,8 @@ sub db_connect {
     my $user = $self->config->{report_store}{user};
     my $pass = $self->config->{report_store}{pass};
 
-    # cacheing
-    if ($self->{grammar} && $self->{dbix}) {
-        my $cached_grammar_type = $self->{grammar}->dsn;
-        if ( $dsn =~ /$cached_grammar_type/ ) {
-            return $self->{dbix};    # caching
-        }
+    if ($self->{grammar} and $self->{grammar}->dsn =~ /$dsn/i) {
+        return $self->{dbix} if $self->{dbix};    # caching
     }
 
     my $needs_tables;
@@ -554,7 +551,6 @@ sub db_connect {
     if ($needs_tables) {
         $self->apply_db_schema($needs_tables);
     }
-
     return $self->{dbix};
 }
 
@@ -682,7 +678,7 @@ Mail::DMARC::Report::Store::SQL - store and retrieve reports from a SQL RDBMS
 
 =head1 VERSION
 
-version 1.20240314
+version 1.20200108
 
 =head1 DESCRIPTION
 
@@ -716,7 +712,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024 by Matt Simerson.
+This software is copyright (c) 2020 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
