@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store::SQL::Grammars::MySQL;
-our $VERSION = '1.20191025';
+our $VERSION = '1.20200108';
 use strict;
 use warnings;
 
@@ -30,8 +30,8 @@ sub report_record_id {
 }
 
 sub delete_from_where_record_in {
-    my ($self, $table, $row_ids) = @_;
-    return "DELETE FROM $table WHERE report_record_id IN ($row_ids)"
+    my ($self, $table) = @_;
+    return "DELETE FROM $table WHERE report_record_id IN (??)"
 }
 
 sub delete_from_where_report {
@@ -290,7 +290,7 @@ Mail::DMARC::Report::Store::SQL::Grammars::MySQL - Grammar for working with mysq
 
 =head1 VERSION
 
-version 1.20191025
+version 1.20200108
 
 =head1 SYPNOSIS
 
@@ -320,7 +320,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Matt Simerson.
+This software is copyright (c) 2020 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
